SERVICES = [
    "asana",
    "atlassian",
    "bitbucket",
    "circleci",
    "close",
    "cloudamqp",
    "cloudflare",
    "codecov",
    "digitalocean",
    "discord",
    "docker",
    "github",
    "gitlab",
    "invision",
    "heroku",
    "mailgun",
    "npm",
    "nylas",
    "pagerduty",
    "personio",
    "pypi",
    "redislabs",
    "salesforce",
    "sentry",
    "servicemax",
    "signal",
    "slack",
    "sparkpost",
    "travis",
    "twilio",
]

__all__ = [SERVICES]
