from statuscheck.services._statuspage import BaseStatusPageAPI


class ServiceAPI(BaseStatusPageAPI):
    name = "ServiceMax"
    domain_id = "jtvt0b51c5wy"
    status_url = "https://servicemax.statuspage.io/"
